==> vradi-entities-0.0.2-sources.jar: com/jurismarches/vradi/entities/Sending.java <==
package com.jurismarches.vradi.entities;

import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntity;

public interface Sending extends BusinessEntity {

	static final public String EXT_SENDING = "Sending";

    static final public String FIELD_SENTDATE = "sentDate";
    static final public String FQ_FIELD_SENTDATE = EXT_SENDING + ".sentDate";
    static final public String FIELD_RECEPTIONDATE = "receptionDate";
    static final public String FQ_FIELD_RECEPTIONDATE = EXT_SENDING + ".receptionDate";
    static final public String FIELD_PARAGRAPH = "paragraph";
    static final public String FQ_FIELD_PARAGRAPH = EXT_SENDING + ".paragraph";
    static final public String FIELD_RECEPTIONPROOF = "receptionProof";
    static final public String FQ_FIELD_RECEPTIONPROOF = EXT_SENDING + ".receptionProof";
    static final public String FIELD_STATUS = "status";
    static final public String FQ_FIELD_STATUS = EXT_SENDING + ".status";
    static final public String FIELD_CLIENT = "client";
    static final public String FQ_FIELD_CLIENT = EXT_SENDING + ".client";
    static final public String FIELD_FORM = "form";
    static final public String FQ_FIELD_FORM = EXT_SENDING + ".form";

    public void setSentDate(Date sentDate);
    public Date getSentDate();


    public void setReceptionDate(Date receptionDate);
    public Date getReceptionDate();


    public void setParagraph(String paragraph);
    public String getParagraph();


    public void setReceptionProof(boolean receptionProof);
    public boolean getReceptionProof();


    public void setStatus(String status);
    public String getStatus();


    public void setClient(String client);
    public String getClient();

    public Set<String> getForm();
    public void addForm(String element);
    public void removeForm(String element);
    public void clearForm();


} //Sending

==> vradi-entities-0.0.3-sources.jar: com/jurismarches/vradi/entities/Sending.java <==
package com.jurismarches.vradi.entities;

import java.util.Date;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntity;

public interface Sending extends BusinessEntity {

	static final public String EXT_SENDING = "Sending";

    static final public String FIELD_SENTDATE = "sentDate";
    static final public String FQ_FIELD_SENTDATE = EXT_SENDING + ".sentDate";
    static final public String FIELD_RECEPTIONDATE = "receptionDate";
    static final public String FQ_FIELD_RECEPTIONDATE = EXT_SENDING + ".receptionDate";
    static final public String FIELD_PARAGRAPH = "paragraph";
    static final public String FQ_FIELD_PARAGRAPH = EXT_SENDING + ".paragraph";
    static final public String FIELD_RECEPTIONPROOF = "receptionProof";
    static final public String FQ_FIELD_RECEPTIONPROOF = EXT_SENDING + ".receptionProof";
    static final public String FIELD_STATUS = "status";
    static final public String FQ_FIELD_STATUS = EXT_SENDING + ".status";
    static final public String FIELD_CLIENT = "client";
    static final public String FQ_FIELD_CLIENT = EXT_SENDING + ".client";
    static final public String FIELD_FORM = "form";
    static final public String FQ_FIELD_FORM = EXT_SENDING + ".form";

    public void setSentDate(Date sentDate);
    public Date getSentDate();


    public void setReceptionDate(Date receptionDate);
    public Date getReceptionDate();


    public void setParagraph(String paragraph);
    public String getParagraph();


    public void setReceptionProof(boolean receptionProof);
    public boolean getReceptionProof();


    public void setStatus(int status);
    public int getStatus();


    public void setClient(String client);
    public String getClient();

    public Set<String> getForm();
    public void addForm(String element);
    public void removeForm(String element);
    public void clearForm();


} //Sending
